Open source Terminal Investment Simulation
==========================================

OpenTISim is a python package for the evaluation of investment decisions for terminals.

Welcome to OpenTISim documentation! Please check the contents below for information on installation, getting started and actual example code. If you want to dive straight into the code you can check out our `GitHub`_ page or the working examples presented in `Jupyter Notebooks`_.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   installation
   opentisim
   contributing
   authors
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _GitHub: https://github.com/TUDelft-CITG/OpenTISim
.. _Jupyter Notebooks: https://github.com/TUDelft-CITG/OpenTISim-Notebooks